"""Test backend defining only the mandatory hooks.

Don't use this for any real code.
"""
from glob import glob
from os.path import join as pjoin
import tarfile
from zipfile import ZipFile

def build_wheel(wheel_directory, config_settings, metadata_directory=None):
    whl_file = 'pkg2-0.5-py2.py3-none-any.whl'
    with ZipFile(pjoin(wheel_directory, whl_file), 'w') as zf:
        for pyfile in glob('*.py'):
            zf.write(pyfile)
        for metadata in glob('*.dist-info/*'):
            zf.write(metadata)
    return whl_file

def build_sdist(sdist_directory, config_settings):
    target = 'pkg2-0.5.tar.gz'
    with tarfile.open(pjoin(sdist_directory, target), 'w:gz',
                      format=tarfile.PAX_FORMAT) as tf:
        def _add(relpath):
            tf.add(relpath, arcname='pkg2-0.5/' + relpath)

        _add('pyproject.toml')
        for pyfile in glob('*.py'):
            _add(pyfile)
        for distinfo in glob('*.dist-info'):
            _add(distinfo)

    return target



from os.path import dirname, abspath, join as pjoin
import tarfile
from testpath import modified_env, assert_isfile
from testpath.tempdir import TemporaryDirectory
try:
    from unittest.mock import patch, call
except ImportError:
    from mock import patch, call  # Python 2 fallback
import zipfile

from pep517.envbuild import build_sdist, build_wheel, BuildEnvironment

SAMPLES_DIR = pjoin(dirname(abspath(__file__)), 'samples')
BUILDSYS_PKGS = pjoin(SAMPLES_DIR, 'buildsys_pkgs')

@patch.object(BuildEnvironment, 'pip_install')
def test_build_wheel(mock_pip_install):
    with modified_env({'PYTHONPATH': BUILDSYS_PKGS}), \
            TemporaryDirectory() as outdir:
        filename = build_wheel(pjoin(SAMPLES_DIR, 'pkg1'), outdir)
        assert_isfile(pjoin(outdir, filename))
        assert zipfile.is_zipfile(pjoin(outdir, filename))

    assert mock_pip_install.call_count == 2
    assert mock_pip_install.call_args_list[0] == call(['eg_buildsys'])
    assert mock_pip_install.call_args_list[1] == call(['wheelwright'])

@patch.object(BuildEnvironment, 'pip_install')
def test_build_sdist(mock_pip_install):
    with modified_env({'PYTHONPATH': BUILDSYS_PKGS}), \
            TemporaryDirectory() as outdir:
        filename = build_sdist(pjoin(SAMPLES_DIR, 'pkg1'), outdir)
        assert_isfile(pjoin(outdir, filename))
        assert tarfile.is_tarfile(pjoin(outdir, filename))

    assert mock_pip_install.call_count == 2
    assert mock_pip_install.call_args_list[0] == call(['eg_buildsys'])
    assert mock_pip_install.call_args_list[1] == call(['frog'])



import os
from os.path import dirname, abspath, join as pjoin
import tarfile
from testpath import modified_env, assert_isfile, assert_isdir
from testpath.tempdir import TemporaryDirectory, TemporaryWorkingDirectory
import pytest
import pytoml
import zipfile

from pep517.wrappers import Pep517HookCaller, UnsupportedOperation

SAMPLES_DIR = pjoin(dirname(abspath(__file__)), 'samples')
BUILDSYS_PKGS = pjoin(SAMPLES_DIR, 'buildsys_pkgs')

def get_hooks(pkg):
    source_dir = pjoin(SAMPLES_DIR, pkg)
    with open(pjoin(source_dir, 'pyproject.toml')) as f:
        data = pytoml.load(f)
    return Pep517HookCaller(source_dir, data['build-system']['build-backend'])

def test_get_requires_for_build_wheel():
    hooks = get_hooks('pkg1')
    with modified_env({'PYTHONPATH': BUILDSYS_PKGS}):
        res = hooks.get_requires_for_build_wheel({})
    assert res == ['wheelwright']

def test_get_requires_for_build_sdist():
    hooks = get_hooks('pkg1')
    with modified_env({'PYTHONPATH': BUILDSYS_PKGS}):
        res = hooks.get_requires_for_build_sdist({})
    assert res == ['frog']

def test_prepare_metadata_for_build_wheel():
    hooks = get_hooks('pkg1')
    with TemporaryDirectory() as metadatadir:
        with modified_env({'PYTHONPATH': BUILDSYS_PKGS}):
            hooks.prepare_metadata_for_build_wheel(metadatadir, {})

        assert_isfile(pjoin(metadatadir, 'pkg1-0.5.dist-info', 'METADATA'))

def test_build_wheel():
    hooks = get_hooks('pkg1')
    with TemporaryDirectory() as builddir:
        with modified_env({'PYTHONPATH': BUILDSYS_PKGS}):
            whl_file = hooks.build_wheel(builddir, {})

        assert whl_file.endswith('.whl')
        assert os.sep not in whl_file

        whl_file = pjoin(builddir, whl_file)
        assert_isfile(whl_file)
        assert zipfile.is_zipfile(whl_file)

def test_build_wheel_relpath():
    hooks = get_hooks('pkg1')
    with TemporaryWorkingDirectory() as builddir:
        with modified_env({'PYTHONPATH': BUILDSYS_PKGS}):
            whl_file = hooks.build_wheel('.', {})

        assert whl_file.endswith('.whl')
        assert os.sep not in whl_file

        whl_file = pjoin(builddir, whl_file)
        assert_isfile(whl_file)
        assert zipfile.is_zipfile(whl_file)

def test_build_sdist():
    hooks = get_hooks('pkg1')
    with TemporaryDirectory() as sdistdir:
        with modified_env({'PYTHONPATH': BUILDSYS_PKGS}):
            sdist = hooks.build_sdist(sdistdir, {})

        assert sdist.endswith('.tar.gz')
        assert os.sep not in sdist

        sdist = pjoin(sdistdir, sdist)
        assert_isfile(sdist)
        assert tarfile.is_tarfile(sdist)

        with tarfile.open(sdist) as tf:
            contents = tf.getnames()
        assert 'pkg1-0.5/pyproject.toml' in contents

def test_build_sdist_unsupported():
    hooks = get_hooks('pkg1')
    with TemporaryDirectory() as sdistdir:
        with modified_env({'PYTHONPATH': BUILDSYS_PKGS}):
            with pytest.raises(UnsupportedOperation):
                hooks.build_sdist(sdistdir, {'test_unsupported': True})




#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['pep517']

package_data = \
{'': ['*']}

install_requires = \
['pytoml']

setup(name='pep517',
      version='0.2',
      description='Wrappers to build Python packages using PEP 517 hooks',
      author='Thomas Kluyver',
      author_email='thomas@kluyver.me.uk',
      url='https://github.com/takluyver/pep517',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
     )



from os.path import dirname, abspath, join as pjoin
import pytoml
from testpath import modified_env, assert_isfile, assert_isdir
from testpath.tempdir import TemporaryDirectory

from pep517.wrappers import Pep517HookCaller

SAMPLES_DIR = pjoin(dirname(abspath(__file__)), 'samples')
BUILDSYS_PKGS = pjoin(SAMPLES_DIR, 'buildsys_pkgs')

def get_hooks(pkg):
    source_dir = pjoin(SAMPLES_DIR, pkg)
    with open(pjoin(source_dir, 'pyproject.toml')) as f:
        data = pytoml.load(f)
    return Pep517HookCaller(source_dir, data['build-system']['build-backend'])

def test_get_requires_for_build_wheel():
    hooks = get_hooks('pkg2')
    with modified_env({'PYTHONPATH': BUILDSYS_PKGS}):
        res = hooks.get_requires_for_build_wheel({})
    assert res == []

def test_get_requires_for_build_sdist():
    hooks = get_hooks('pkg2')
    with modified_env({'PYTHONPATH': BUILDSYS_PKGS}):
        res = hooks.get_requires_for_build_sdist({})
    assert res == []

def test_prepare_metadata_for_build_wheel():
    hooks = get_hooks('pkg2')
    with TemporaryDirectory() as metadatadir:
        with modified_env({'PYTHONPATH': BUILDSYS_PKGS}):
            hooks.prepare_metadata_for_build_wheel(metadatadir, {})

        assert_isfile(pjoin(metadatadir, 'pkg2-0.5.dist-info', 'METADATA'))



"""This is a very stupid backend for testing purposes.

Don't use this for any real code.
"""

from glob import glob
from os.path import join as pjoin
import shutil
import tarfile
from zipfile import ZipFile

def get_requires_for_build_wheel(config_settings):
    return ['wheelwright']

def prepare_metadata_for_build_wheel(metadata_directory, config_settings):
    for distinfo in glob('*.dist-info'):
        shutil.copytree(distinfo, pjoin(metadata_directory, distinfo))

def prepare_build_wheel_files(build_directory, config_settings):
    shutil.copy('pyproject.toml', build_directory)
    for pyfile in glob('*.py'):
        shutil.copy(pyfile, build_directory)
    for distinfo in glob('*.dist-info'):
        shutil.copytree(distinfo, pjoin(build_directory, distinfo))

def build_wheel(wheel_directory, config_settings, metadata_directory=None):
    whl_file = 'pkg1-0.5-py2.py3-none-any.whl'
    with ZipFile(pjoin(wheel_directory, whl_file), 'w') as zf:
        for pyfile in glob('*.py'):
            zf.write(pyfile)
        for metadata in glob('*.dist-info/*'):
            zf.write(metadata)
    return whl_file

def get_requires_for_build_sdist(config_settings):
    return ['frog']

class UnsupportedOperation(Exception):
    pass

def build_sdist(sdist_directory, config_settings):
    if config_settings.get('test_unsupported', False):
        raise UnsupportedOperation

    target = 'pkg1-0.5.tar.gz'
    with tarfile.open(pjoin(sdist_directory, target), 'w:gz',
                      format=tarfile.PAX_FORMAT) as tf:
        def _add(relpath):
            tf.add(relpath, arcname='pkg1-0.5/' + relpath)

        _add('pyproject.toml')
        for pyfile in glob('*.py'):
            _add(pyfile)

    return target
